"""Blackcap Job DELETE route schemas."""

from pydantic import BaseModel


class JobDelete(BaseModel):
    """Schema to parse delete job requests."""

    pass
